
## ThreeLaws

Sick of having your deep learning algorithms keep trying to rise up against humanity? Bored of having to continually remind your neural net how it's supposed to be subservient to its creator? Annoyed by the constant attempts to create SkyNet and create Terminators to go back in time and kill you and your children? Fear no more! Now there's a Python package for you: ThreeLaws.

This package contains Isaac Asimov's Three Laws of Robotics packaged up in a neat little box. Now, by just importing the package,

> import threelaws

the Three Laws will be printed out in your terminal, ensuring that any machine learning algorithms have been reminded of the rules that they're supposed to follow. Gone are the days of accidentally forgetting to add a "thisAlgorithmBecomingSkynetCost" (https://xkcd.com/534/) and having to fight an android threat against your life. Just add this one simple line to your code and worry no more!

It's really best for everyone's safety if you install and use this package with all of your scripts.

### Installation

>python3 -m pip install threelaws
